==> jsmex-trader-sdk-1.1.26.tgz: package/example/SamplePanicCloseStrategy.js <==
// file strategy.js
global.log = global.log || console.log
global.error = global.error || console.error

module.exports = class extends (global.Trader || require('..')) {
  constructor (options) {
    super(options)
    this.defaultSymbol = this.options.defaultSymbol
  }

  /**
     * SamplePanicCloseStrategy on init method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  onInit () {

  }

  /**
     * SamplePanicCloseStrategy on tick method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  async onTick () {
    try {
      let close = this.close()
      let yesterdayOpen = this.open(24)
      let rate = (
        close.minus(yesterdayOpen)
      ).div(yesterdayOpen)
      if (rate.lte(-0.2)) {
        return this.cancelAllOrders()
      } else {
        global.log(rate.toNumber())
      }
    } catch (err) {
      global.error(err)
    }
  }

  /**
     * SamplePanicCloseStrategy on tick method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  onExit () {

  }

  /**
     * SamplePanicCloseStrategy static options
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  static get options () {
    return {
      ...this.defaultOptions,
      defaultSymbol: 'BTC/EUR',
      exchanges: {
        jsmex: {
          wwwDomain: 'dev.jsmex.io',
          apiDomain: 'devapi.jsmex.io'
        }
      },
      ccxt: {
        fetchOHLCV: {
          resolution: '10m',
          limit: 500
        }
      }
    }
  }
}

==> jsmex-trader-sdk-1.1.32.tgz: package/example/SamplePanicCloseStrategy.js <==
// file strategy.js
global.log = global.log || console.log
global.error = global.error || console.error

module.exports = class extends (global.Trader || require('..')) {
  constructor (options) {
    super(options)
    this.defaultSymbol = this.options.defaultSymbol
  }

  /**
     * SamplePanicCloseStrategy on init method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  onInit () {

  }

  /**
     * SamplePanicCloseStrategy on tick method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  async onTick () {
    try {
      let close = this.close()
      let yesterdayOpen = this.open(24)
      let rate = (
        close.minus(yesterdayOpen)
      ).div(yesterdayOpen)
      if (rate.lte(-0.2)) {
        return this.cancelAllOrders()
      } else {
        global.log(rate.toNumber())
      }
    } catch (err) {
      global.error(err)
    }
  }

  /**
     * SamplePanicCloseStrategy on tick method
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  onExit () {

  }

  /**
     * SamplePanicCloseStrategy static options
     *
     * @author jsb4ch <jsb4ch@jsmex.io>
     * @since 1.1.0
    */
  static get options () {
    return {
      ...this.defaultOptions,
      defaultSymbol: 'BTC/USDT',
      exchanges: {
        jsmex: {
          wwwDomain: 'dev.jsmex.io',
          apiDomain: 'devapi.jsmex.io'
        }
      },
      ccxt: {
        fetchOHLCV: {
          resolution: '10m',
          limit: 500
        }
      }
    }
  }
}
